<?php
function bynder_parse_url($url) {
    if (empty($url)) {
        return '';
    }
    $parsedUrl = parse_url($url);
    // If the URL is seriously malformed, parse URL returns false.
    if ($parsedUrl === false) {
        return null;
    }
    // The scheme is required and should be either http or https.
    if (empty($parsedUrl['scheme']) || strtolower($parsedUrl['scheme']) != 'https') {
        return null;
    }
    // The host is required and may consist only of letters, numbers, '-' or '.'.
    // The host can't start or end with '-' or '.'.
    // The host can't contain the sequences '--', '-.', '..' or '.-'.
    if (empty($parsedUrl['host']) || !preg_match('/^[\w\d]([\-\.]?[\w\d]+)*$/i', $parsedUrl['host'])) {
        return null;
    }
    // URLs which contain a port, user, pass or fragment are not supported and considered invalid.
    if (!empty($parsedUrl['port']) || !empty($parsedUrl['user']) || !empty($parsedUrl['pass']) || !empty($parsedUrl['fragment'])) {
        return null;
    }
    return htmlspecialchars($parsedUrl['scheme'].'://'.$parsedUrl['host']);
}
?>